package PAR::Repository::Web::View::TToolkit;

use strict;
use base 'Catalyst::View::TT';

=head1 NAME

PAR::Repository::Web::View::TToolkit - Catalyst TT View

=head1 SYNOPSIS

See L<PAR::Repository::Web>

=head1 DESCRIPTION

Catalyst TT View.

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2008 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
